package com.xydl.cac.controller;

import com.xydl.cac.entity.I2syncConfig;
import com.xydl.cac.entity.I2syncRecord;
import com.xydl.cac.entity.ModevType;
import com.xydl.cac.exception.BusinessException;
import com.xydl.cac.model.Response;
import com.xydl.cac.service.I2syncService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@Api(tags = {"I2同步数据相关接口"})
@RequestMapping("i2sync")
@Slf4j
public class I2syncController extends BasicController {

    @Resource
    I2syncService service;

    @GetMapping("listFieldConfig")
    @ApiOperation("查询字段映射")
    public Response<List<ModevType>> listFieldConfig() {
        List<ModevType> result = service.listFieldConfig();
        return Response.success(result);
    }

    @PostMapping("updateFieldConfig")
    @ApiOperation("修改字段映射")
    public Response<String> updateFieldConfig(@Validated @RequestBody ModevType item) throws Exception {
        if (CollectionUtils.isEmpty(item.getI2syncFields())) {
            throw new BusinessException("i2syncFields不能为空!");
        }
        service.updateFieldConfig(item);
        return Response.success("OK");
    }

    @PostMapping("delFieldConfig")
    @ApiOperation("删除字段映射")
    public Response<String> delFieldConfig(@Validated @RequestBody ModevType item) throws Exception {
        service.delFieldConfig(item.getTablename());
        return Response.success("OK");
    }

    @GetMapping("listConfig")
    @ApiOperation("查询导出类型配置")
    public Response<List<I2syncConfig>> listConfig() {
        List<I2syncConfig> result = service.listConfig();
        return Response.success(result);
    }

    @PostMapping("addConfig")
    @ApiOperation("新增导出类型配置")
    public Response<String> addConfig(@Validated @RequestBody I2syncConfig item) throws Exception {
        service.addConfig(item);
        return Response.success("OK");
    }

    @PostMapping("delConfig")
    @ApiOperation("删除导出类型配置")
    public Response<String> delConfig(@Validated @RequestBody I2syncConfig item) throws Exception {
        if (item.getId() == null) {
            throw new BusinessException("id不能为空!");
        }
        service.delConfig(item.getId());
        return Response.success("OK");
    }

    @GetMapping("listRecord")
    @ApiOperation("查询导出记录")
    public Response<List<I2syncRecord>> listRecord(Integer modevtypeId) {
        List<I2syncRecord> result = service.listRecord(modevtypeId);
        return Response.success(result);
    }

}
